勇敢的心 (豆瓣)
Description: 勇敢的心电影简介和剧情介绍,勇敢的心影评、图片、预告片、影讯、论坛、在线购票
Keywords: 勇敢的心,Braveheart,勇敢的心影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.106豆瓣电影Top250

# 勇敢的心 Braveheart (1995)

导演: 梅尔·吉布森
编剧: 兰道尔·华莱士
主演: 梅尔·吉布森 / 苏菲·玛索 / 布莱恩·考克斯 / 詹姆斯·科兹莫 / 辛·劳洛 / 凯瑟琳·麦克马克 / 安古斯·麦克菲登
类型: 剧情 / 动作 / 传记 / 历史 / 战争
制片国家/地区: 美国
语言: 英语 / 法语 / 拉丁语 / 苏格兰盖尔语
上映日期: 1995-05-18(西雅图电影节) / 1995-05-24(美国)
片长: 178分钟
又名: 惊世未了缘(港) / 梅尔吉勃逊之英雄本色(台)
IMDb: tt0112573
豆瓣评分
引用
8.9
540721人评价
5星
56.3%
4星
34.2%
3星
8.6%
2星
0.7%
1星
0.2%
好于 98% 战争片
好于 98% 历史片
想看 看过
评价:
推荐

## 勇敢的心的剧情简介 · · · · · ·

威廉•华莱士童年时，其父、苏格兰民族英雄马索•华莱士在与英军的斗争中牺牲，他开始接受父亲好友的指导，学习苏格兰文化和武术。青年华莱士（梅尔•吉布森）学成回到故乡，向美丽的少女梅伦求婚，不想梅伦被英军抢去且遭杀害。在广大村民“英雄之后”的呼声中，华莱士率众揭竿起义，并与苏格兰贵族罗伯结成联盟，但不久他发现，苏格兰贵族考虑的只是自身的利益。
英王为缓和局势，派伊莎贝拉（苏菲•玛索）前去和华莱士谈判，由于英王只想收买华莱士，根本不顾苏格兰人民的自由和平等，谈判失败，但这一切并不为伊莎贝拉所知。伊莎贝拉归国后发现事情真相，且知晓英王正策划阴招，忙送信给华莱士，而两人的爱情，也在战争与阴谋中悄然滋生。 ©豆瓣

## 勇敢的心的演职员 · · · · · · ( 全部 53 )

- 梅尔·吉布森 导演
- 梅尔·吉布森 饰 William Wallace
- 苏菲·玛索 饰 Princess Isabelle
- 布莱恩·考克斯 饰 Argyle Wallace
- 詹姆斯·科兹莫 饰 Campbell
- 辛·劳洛 饰 Malcolm Wallace

## 勇敢的心的视频和图片 · · · · · · ( 预告片1 | 添加视频评论 | 图片961 · 添加 )

## 勇敢的心的获奖情况 · · · · · · ( 全部 )

- 第68届奥斯卡金像奖
- 最佳影片
- 艾伦·拉德二世 / 梅尔·吉布森 / 布鲁斯·戴维

- 第53届金球奖
- 电影类 最佳剧情片(提名)

- 第49届英国电影学院奖
- 电影奖 最佳导演(提名)
- 梅尔·吉布森

## 喜欢这部电影的人也喜欢 · · · · · ·

  拯救大兵瑞恩

  角斗士

  兵临城下

  辛德勒的名单

  黑鹰坠落

  指环王3：王者无敌

  钢琴家

  血战钢锯岭

  与狼共舞

  战争之王

我要写短评

## 勇敢的心的短评 · · · · · · ( 全部 95274 条 )

热门 / 最新 / 好友

### 3198 有用 老阿飞—故园 看过 2007-08-26 14:48:43

一句“freedom”煽的我眼泪哗哗的

### 1933 有用 老鸡｜扶立 看过 2008-01-10 16:29:33

有时候男人的一句嘶吼也可以让人流泪

### 1328 有用 影志 看过 2006-02-04 06:07:48

那时候的史诗片拍的多好，90年代的大片就应该是这样的。

### 448 有用 冰红深蓝 看过 2014-04-15 15:30:11

梅尔吉布森自导自演，斩获奥斯卡多项大奖。这部影片从史实角度看完全不及格，但从史诗角度看绝对堪称经典。童年苦情经历、爱情、复仇、战争、背叛、受刑等英雄片的元素齐集，配以高潮迭起的剧情和悠扬的苏格兰风笛，让人即使知道剧情与史实不符，也禁不住流泪。（8.5/10）

### 2729 有用 今天小熊不吃糖 看过 2010-06-20 10:25:24

所有的人都会死，但并不是每一个人都活的有意义。

> 更多短评 95274条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 勇敢的心的影评 · · · · · · ( 全部 1226 条 )

热门 / 最新 / 好友
fxy 2006-08-30 15:59:35

## 经典就是经典

记的看这部片子时还在上初中,当时就很喜欢这部片子,这些年看的好莱坞电影有几百部,唯一只有这部片子让我反复看了五十多遍,连台词都背下来了~~~~~~ 这些年里还不断煽动家人朋友去看这部片子,为的就是和大家分享真正的经典(虽然这部片子也有bug)许多人和我一起感动了N回........ (展开)
3123 83 305回应 收起
勇敢的心 2007-01-28 01:52:48

## 历史上的 《勇敢的心》----------背景和真实故事

这是我最喜欢的电影，画面，音乐，场面，主题，演员......，一切都可以说Perfect! 说两句题外话吧， 正如影片开始所述，历史总是被一些人改变，不过有些讽刺的是，好莱坞的导演总是干这种事情， 熟悉历史的人知道，这部电影说的是英国著名的金雀花王朝时代的故事。 这个王... (展开)
1308 98 182回应 收起
麦姆姆 2006-07-21 20:00:29

## 勇敢的心

当苏格兰风笛的声音奏响，镜头像戴在鸟的翅膀上一样，幽雅地掠过藏青色的山峦，白雾从小河上升腾起再散开，镜头不断地拉近，树林间出现了人马的影子，电影就开始了。一个男人的声音在此时响起：“我将为你们讲述威廉姆华莱士的故事，英国的历史学家们会说我在说谎，但历史是由... (展开)
726 48 134回应 收起
风中散发 2005-09-13 20:51:31

## 煽情

影片中的华莱士本来就是一个美国式的英雄，他的意识形态和做事方式非常美国。而历史上的他，我相信在文化层面也很难是一个英国式的反抗者--罗宾汉才是。 故事的背景无非是一个舞台，用来让导演表达自己内心的舞台。我们喜欢这部影片，也是因为我们喜欢纯粹的英雄：率真、勇敢、... (展开)
189 25 23回应 收起
月下独酌 2015-10-21 01:45:48

## 向往自由之心永远不死

梅尔吉布森的这部电影曾深深震撼了我，它史诗般地描述了13世纪苏格兰领袖William Wallce带领苏格兰人民为自由而战的故事，具有深刻的民族主义和政治内涵的古装巨制。 人，需要信仰和精神力量，坚定不移地坚持自己的信仰令人钦佩。华莱士临刑前响彻天际的那一... (展开)
81 6 2回应 收起
snowflake 2016-04-12 04:26:15

## 追求自由的灵魂

一部荡气回肠的英雄史诗，一个看后让人潸然泪下的故事，一部悲壮的血泪传奇。 影片讲述了苏格兰人反抗英格兰的历史。没有人生来喜欢流血和战争，华莱士也同样，他希望能安分守己地过日子，憧憬自由平静的生活。可是这一切都因为他妻子的死而改变了，他开始醒悟，开始反抗，... (展开)
70 7 1回应 收起
艾小柯 2006-06-21 01:56:22

## 浪漫的英雄主义

其实，在决定写下《勇敢的心》之前，我稍微犹豫了几秒钟。 这倒不是因为我怀疑它在我记忆中的重要程度，而是我有些担心写下这样一部程式化的梅尔·吉布森电影太过庸俗。不过我马上就为自己的担心而感到更加庸俗。不能忠于自我只会使一切感受记忆想法变成了人云亦云，失去所有... (展开)
87 16 14回应 收起
昨夜星辰恰似你 2017-07-29 23:37:06

## 经典十句

(1)WILLIAM WALLACE：“Fight,and you may die.Run,and you''ll live at least a while. 　　And dying in your beds many years from now. 　　Would you be willing to trade? 　　All the days from this day to that, 　　for one chance,just one chance, 　　to come bac... (展开)
85 2 4回应 收起
万人非你 2018-03-19 16:31:10

## 勇敢的心

英雄是时代造就的，但不是所有历史上的英雄都能造就了一个新的时代。很多人揭竿而起，为自己的信念而战，然而很少有人能站着迎接胜利的到来。一批有一批的人倒下，紧之后是一批有一批的人站起来，其实他们早就把生死置之度外，或许，他们愿意用自己的生命去换取他们心中的信念... (展开)
45 1 1回应 收起
爱吃糖的猫 2017-04-12 10:32:51

## 铁骨柔情也可以荡气回肠

这篇影评可能有剧透

成长道路上总是要经历着什么才能真正长大，本片也不例外。华莱士成长，是建立在在失去了父亲以后。他也曾是个天真烂漫的小孩子，当他看到那个小屋里被人吊死的同胞，他受到了惊吓。他的父亲哥哥死后，他开始变得勇敢，即使面对他父亲和哥哥的遗体，也是一样平静自若。再后来，... (展开)
52 33 2回应 收起

> 更多影评 1226篇

添加新讨论

## 讨论区 · · · · · ·

我可以理解男主和苏菲上床 | 来自贾夫纳 | 9 回应 | 2022-11-24 19:21:10
华莱士结婚时候不是说除了你不会有别人吗 | 来自没注销 | 21 回应 | 2022-10-25 14:20:57
杨志刚 | 来自米粒1448128683 | 2 回应 | 2022-10-05 09:39:27
这要是美国人拍个努尔哈赤 | 来自絮絮 | 7 回应 | 2022-10-01 15:02:40
台湾的译名居然叫梅尔吉普森之英雄本色！ | 来自易 | 21 回应 | 2022-10-01 14:55:49

> 去这部影片的讨论区（全部268条）

## 关于《勇敢的心》的问题 · · · · · · ( 全部10个 )

- 现在到处都有的“华莱士”炸鸡店和这个华莱士有什么联系吗？ 7人回答
- 背景音乐叫什么名字？ 5人回答

> 全部10个问题

## 在哪儿看这部电影 · · · · · ·

- 爱奇艺视频 VIP免费观看
- 腾讯视频 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

## 谁在看这部电影 · · · · · ·

- 身体大师
  刚刚 看过
- 沉默是最好的
  5分钟前 看过
- 豆友O4WfE_FJiI
  14分钟前 看过

869043人看过 / 250690人想看

订阅勇敢的心的评论:
feed: rss 2.0